import time
import execjs

class Agent:
    def __init__(self, agent_id, js_function):
        self.id = agent_id
        self.function = js_function  # JavaScriptコード (String)
        self.last_update = time.time()  # 最終更新日時

        # 受け取った関数を `main` という名前に変換
        wrapped_js_function = f"""
        {js_function}

        function main(input) {{
            return stateActionHandler(input);  // 受け取った関数を `main` として実行
        }}
        """

        # execjs用にコンパイル
        self.ctx = execjs.compile(wrapped_js_function)
        self.history = []  # 実行履歴を保存

    def execute(self, input_data):
        """エージェントの関数を実行し、評価関数があれば評価を記録"""
        output = self.ctx.call("main", input_data)

        # 結果を履歴に保存（指定のオブジェクト形式）
        action_record = {"i": input_data, "o": output}
        self.history.append(action_record)

        return output
    
    